@@ -2,6 +2,8 @@
 
 import os
 import sys
+from . import icmp
+from . import network
 
 # Python 3.5 compatibility
 if sys.version_info[1] == 5:
@@ -27,16 +29,6 @@ else:
         All = auto()
 
 
-from . import icmp
-from . import network
-
-
-class SuccessOn(IntEnum):
-    One = auto()
-    Most = auto()
-    All = auto()
-
-
 class Message:
     """Represents an ICMP message with destination socket"""
     def __init__(self, target, packet, source):
